==> tine20-allinone_2019.12.5.tar.bz2: ActiveSync/js/ActiveSync-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ru\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "SyncDevice, SyncDevices"
: [
  "Устройство"
 ,"Устройства"
 ,"Устройств"
 ,"Устройств"

]
, "Sync Devices"
: "Устройства"

, "ID"
: "ID"

, "Device ID"
: "ID устройства"

, "Devicetype"
: "Тип устройства"

, "Owner"
: "Владелец"

, "Policy"
: "Политика"

, "AS Version"
: "Версия AS"

, "Useragent"
: "Приложение"

, "Model"
: "Модель"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Простое имя"

, "OS"
: "ОС"

, "OS Language"
: "Язык ОС"

, "Phonenumber"
: "Номер телефона"

, "Ping Lifetime"
: "Пинг"

, "Ping Folder"
: "Папка для пинга"

, "Remote Wipe"
: "Удаленный сброс"

, "Calendarfilter"
: "Фильтр календаря"

, "Contactsfilter"
: "Фильтр контактов"

, "Emailfilter"
: "Фильтр email"

, "Tasksfilter"
: "Фильтр задач"

, "Last Ping"
: "Последний пинг"

, "Remote Reset Device"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device is reset to factory settings!"
: ""

, "Quicksearch"
: "Быстрый поиск"

, "Device, Devices"
: [
  "Устройство"
 ,"Устройства"
 ,"Устройства"
 ,"Устройства"

]
, "Devices"
: "Устройства"

, "Active Sync"
: "Active Sync"

, "Select a Device"
: "Выберите устройство"

, "No ActiveSync Device registered"
: "Устройство ActiveSync не зарегистрировано"

, "Set as {0} Filter"
: "Установить как {0} фильтр"

, "Resetted Sync Filter"
: "Сброшенный фильтр синхронизации"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} фильтр для устройства \"{1}\" сейчас \"{2}\""

, "resetted"
: "сброшен"

, "Set Sync Filter"
: "Установить фильтр синхронизации"

, "Default Addressbook"
: "Адресная книга по умолчанию"

, "The default addressbook to create new contacts in."
: "Адресная книга для создания контактов по умолчанию"

, "Default Calendar"
: "Календарь по умолчанию"

, "The default calendar to create new events in."
: "Календарь для создания новых событий по умолчанию"

, "Default Task List"
: "Список задач по умолчанию"

, "The default task list to create new tasks in."
: "Список задач для создания новых задач по умолчанию"

, "Default policy for new devices"
: "Политика по умолчанию для новых устройств"

, "Enter the id of the policy to apply to newly created devices."
: "Введите ID политики для применения к вновь созданным устройствам."

, "Disable Access Log"
: "Отключить лог"

, "Disable ActiveSync Access Log creation."
: "Отключить создание лога подключений ActiveSync"

, "Filter timeslot for emails"
: "Фильтрация писем по времени"

, "For how long in the past the emails should be synchronized."
: "Насколько давние письма должны быть синхронизированы."

, "Filter timeslot for events"
: "Фильтрация событий по времени"

, "For how long in the past the events should be synchronized."
: "Насколько давние события должны быть синхронизированы."

, "Manage ActiveSync devices"
: "Управление устройствами ActiveSync"

, "See, edit and delete ActiveSync devices"
: "Просмотр, изменение или удаление устройств ActiveSync"

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""

, "Default Policy"
: "Политика по умолчанию"

, "Default Policy installed during setup"
: "Политика по умолчанию заданная при установке"

, "SyncDevice"
: "Устройство"

, "Device"
: "Устройство"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: ActiveSync/js/ActiveSync-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Календарь по умолчанию"

, "The default calendar to create new events in."
: "Календарь для создания новых событий по умолчанию"

, "Default Task List"
: "Список задач по умолчанию"

, "The default task list to create new tasks in."
: "Список задач для создания новых задач по умолчанию"

, "Sync Devices"
: "Устройства"

, "Device ID"
: "ID устройства"

, "Devicetype"
: "Тип устройства"

, "Owner"
: "Владелец"

, "Policy"
: "Политика"

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: "Модель"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Простое имя"

, "OS"
: "ОС"

, "OS Language"
: "Язык ОС"

, "Phonenumber"
: "Номер телефона"

, "Sync Device, Sync Devices"
: [
  ""
 ,""
 ,""
 ,""

]
, "Device, Devices"
: [
  "Устройство"
 ,"Устройства"
 ,"Устройства"
 ,"Устройства"

]
, "Devices"
: "Устройства"

, "Active Sync"
: "Active Sync"

, "Select a Device"
: "Выберите устройство"

, "No ActiveSync Device registered"
: "Устройство ActiveSync не зарегистрировано"

, "Set as {0} Filter"
: "Установить как {0} фильтр"

, "Resetted Sync Filter"
: "Сброшенный фильтр синхронизации"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} фильтр для устройства \"{1}\" сейчас \"{2}\""

, "resetted"
: "сброшен"

, "Set Sync Filter"
: "Установить фильтр синхронизации"

, "ID"
: "ID"

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: "Пинг"

, "Ping Folder"
: "Папка для пинга"

, "Remote Wipe"
: "Удаленный сброс"

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: "Последний пинг"

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: "Быстрый поиск"

, "Default Policy"
: "Политика по умолчанию"

, "Default Policy installed during setup"
: "Политика по умолчанию заданная при установке"

, "Default policy for new devices"
: "Политика по умолчанию для новых устройств"

, "Enter the id of the policy to apply to newly created devices."
: "Введите ID политики для применения к вновь созданным устройствам."

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Отключить лог"

, "Disable ActiveSync Access Log creation."
: "Отключить создание лога подключений ActiveSync"

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: "Фильтрация событий по времени"

, "For how long in the past the events should be synchronized."
: "Насколько давние события должны быть синхронизированы."

, "Manage ActiveSync devices"
: "Управление устройствами ActiveSync"

, "See, edit and delete ActiveSync devices"
: "Просмотр, изменение или удаление устройств ActiveSync"

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""












, "Sync Device"
: ""

, "Device"
: "Устройство"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
